/* Zgv v3.0 - GIF, JPEG and PBM/PGM/PPM viewer, for VGA PCs running Linux.
 * Copyright (C) 1993-1998 Russell Marks. See README for license details.
 *
 * zgv.h - constants, typedefs.
 */

#define ZGV_VER		"3.0"


#define _PIC_OK			 0
#define _PICERR_NOFILE		-1
#define _PICERR_NOMEM		-2
#define _PICERR_BADMAGIC	-3
#define _PICERR_NOCOLOURMAP	-4
#define _PICERR_NOIMAGE		-5
#define _PICERR_UNSUPPORTED	-6
#define _PICERR_CORRUPT		-7
#define _PICERR_SHOWN_ALREADY	-8
#define _PICERR_ISRLE		-9

typedef struct {
  int width,height;
  int bpp,numcols;
  char type[4];
  } PICINFO;

typedef void (*hffunc)(int,int);

typedef unsigned char byte;

extern int idx_light,idx_medium,idx_dark,idx_black;
extern int tagview_mode;
extern int zgv_ttyfd;

extern void wait_for_foreground(void);

/* vgadrawtext_bmp() needs to know what the current colour is, so... */
extern int current_colour;
#define vga_setcolor(x) vga_setcolor(current_colour=(x))
